#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_SPLATTED_SUM_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_SPLATTED_SUM_HPP_INCLUDED

#include <boost/simd/swar/include/functions/simd/splatted_sum.hpp>

#endif
